(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    137769,       3271]*)
(*NotebookOutlinePosition[    138596,       3300]*)
(*  CellTagsIndexPosition[    138506,       3294]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Methoden der Bioinformatik",
    FontSize->24,
    FontWeight->"Bold"],
  StyleBox[" \n",
    FontSize->12],
  StyleBox["Eine Einf\[UDoubleDot]hrung",
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Marc-Thorsten H\[UDoubleDot]tt und Manuel Dehnert",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Springer-Verlag 2006 (ISBN 3-540-25687-3)",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12]
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell[TextData[{
  "Einf\[UDoubleDot]hrung in das Computeralgebra-Programm ",
  StyleBox["Mathematica",
    FontSlant->"Italic"]
}], "Subtitle",
  Background->RGBColor[0.0901961, 0.462745, 0.396078]],

Cell[TextData[{
  "Um in den folgenden Kapiteln \[UDoubleDot]ber die formale Schilderung \
hinaus hinter die Algorithmen der Bioinformatik zu schauen, \
ben\[ODoubleDot]tigen wir eine geeignete Programmierumgebung. Dieser Schritt \
ist nicht trivial, da er auf eine Ebene bioinformatischer Anwendungen f\
\[UDoubleDot]hrt, die \[UDoubleDot]blicherweise unter der \
Oberfl\[ADoubleDot]che der Softwarepakete verborgen bleibt. Durch die relativ \
kompakte und \[UDoubleDot]bersichtliche Schreibweise und durch das suggestive \
und in Grundz\[UDoubleDot]gen \[UDoubleDot]berschaubare Befehlsinventar \
bietet ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "den idealen \"Pseudocode\" zur algorithmischen Beschreibung \
bioinformatischer Werkzeuge. Zugleich erhalten wir auf diesem Wege nicht nur \
anschauliche und verst\[ADoubleDot]ndliche, sondern sogar recht effiziente \
und anwendbare Implementierungen der Werkzeuge.\n\nDer Erfolg \
programmierbarer Taschenrechner in den achtziger Jahren \
begr\[UDoubleDot]ndete sich letztlich in zwei wichtigen Erweiterungen herk\
\[ODoubleDot]mmlicher Ger\[ADoubleDot]te: die M\[ODoubleDot]glichkeit zu \
automatisieren und die (begrenzte) F\[ADoubleDot]higkeit der unmittelbaren \
Visualisierung von Ergebnissen. F\[UDoubleDot]r den Einsteiger stellt sich ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " anfangs als eine Art programmierbarer Taschenrechner dar. Numerische \
Ausdr\[UDoubleDot]cke werden mit dem Befehl ",
  StyleBox["N[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " in explizite Zahlenwerte \[UDoubleDot]berf\[UDoubleDot]hrt:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[10*2\  + \ 8^3\  - \ 16]\)], "Input"],

Cell[BoxData[
    \(516.`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Aus diesem Beispiel lassen sich schon einige der syntaktischen Eigenarten \
von ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " erschlie\[SZ]en. Ein Befehl B wird typischerweise mit eckigen Klammern \
auf einen Ausdruck a angewendet, B[a]. In unserem Beispiel ist dieses \
Argument a eine Kombination verschiedener elementarer Rechenoperationen; dort \
tauchen neben Rechenzeichen wie \"+\" und \"-\" auch Befehle auf, die sich in \
vielen Programmiersprachen durchgesetzt haben, etwa das \
Multiplikationszeichen \"*\" oder das Symbol f\[UDoubleDot]r das Potenzieren \
\"^\". \[CapitalUDoubleDot]ber jeden Befehl B[ ] in ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "kann man \[UDoubleDot]ber das Hilfsmen\[UDoubleDot] oder explizit \
innerhalb einer Zeile mit der Abfrage ?B weitere Informationen erhalten. F\
\[UDoubleDot]r den Befehl ",
  StyleBox["N[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " hat man etwa"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?N\)\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"N[expr] gives the numerical value of expr. N[expr, n] \
attempts to give a result with n-digit precision.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"N",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print",
  CellTags->"Info3348487723-1833893"]
}, Open  ]],

Cell[TextData[{
  "Der Hyperlink am Ende der Ausgabe verweist dabei auf ein externes \
Hilfsfenster. In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " findet man eine Symbiose aus einer Benutzeroberfl\[ADoubleDot]che, einer \
Bedienung auf Kommandozeilenbasis und der M\[ODoubleDot]glichkeit, eigene \
ausf\[UDoubleDot]hrbare Programme zu schreiben und anzuwenden. \
F\[UDoubleDot]r den erstgenannten Punkt stehen Men\[UDoubleDot]punkte zur \
Verf\[UDoubleDot]gung (etwa Speichern, Kopieren und Einf\[UDoubleDot]gen), \
die auf das aktuelle Fenster wirken. Die Fenster zeigen ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Dateien, ",
  StyleBox["Notebooks",
    FontSlant->"Italic"],
  ", die sich mit den in ihnen sichtbaren Informationen (also den Eingaben \
und Ausgaben) speichern lassen. Die beiden anderen Punkte, Verwendung von \
Kommandozeilen und eigene Programme, handeln von den Inhalten solcher \
Notebooks. Betrachten wir zuerst die einzelnen Kommandozeilen. Auf die \
Erstellung eigener Programme werden wir am Ende dieses Kapitels und nat\
\[UDoubleDot]rlich in den ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkursen der folgenden Kapitel zur\[UDoubleDot]ckkommen. Unsere einfache \
Anwendung des Befehls ",
  StyleBox["N[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", die wir oben diskutiert haben, zeigt schon recht klar, dass es sich \
dabei um einen Dialog zwischen dem Benutzer und dem Rechenprogramm, dem im \
Hintergrund ablaufenden ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Kernel handelt. Auf der linken Seite des Notebook-Fensters gliedern ",
  StyleBox["In",
    FontSlant->"Italic"],
  "- und ",
  StyleBox["Out",
    FontSlant->"Italic"],
  "-Markierungen mit fortlaufenden Nummern diesen Dialog, auf der rechten \
Seite sieht man (in der elektronischen Fassung der Notebooks) eine \
Klammerung, die einzelne Kommandozeilen begrenzt und eine Hierarchisierung \
(z.B. das Zusammengeh\[ODoubleDot]ren von Ein- und Ausgabe) erlaubt.\n\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " stellt eine recht komfortable Bibliothek mathematischer Grundlagen und \
Funktionen zur Verf\[UDoubleDot]gung. So kann man zum Beispiel auf Konstanten \
wie die Zahl \[Pi] explizit zugreifen:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(Pi\)], "Input"],

Cell[BoxData[
    \(\[Pi]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "An der Ausgabe erkennt man, dass in ",
  Cell[BoxData[
      FormBox[
        StyleBox["Mathematica",
          FontSlant->"Italic"], TraditionalForm]]],
  " solche Konstanten als (im Rahmen der Rechnergenauigkeit) exakte Werte \
verwendet und nicht durch eine Zahl mit wenigen Nachkommastellen approximiert \
werden. Eine solche Approximation durch eine Dezimalzahl kann man nun jedoch \
mit dem Befehl ",
  StyleBox["N[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " erzwingen:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[Pi]\)], "Input"],

Cell[BoxData[
    \(3.141592653589793`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Als zweites Argument im Befehl ",
  StyleBox["N[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " l\[ADoubleDot]sst sich die gew\[UDoubleDot]nschte Zahl der \
Nachkommastellen dieser Approximation angeben. Hier erh\[ADoubleDot]lt man \
einen ersten Eindruck von der Leistungsf\[ADoubleDot]higkeit dieses \
Programms, da die Ausgabe von 500 Nachkommastellen der Zahl \[Pi] ohne \
Schwierigkeiten m\[ODoubleDot]glich ist."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[Pi, 500]\)], "Input"],

Cell[BoxData[
    \(3.1415926535897932384626433832795028841971693993751058209749445923078164\
062862089986280348253421170679821480865132823066470938446095505822317253594081\
284811174502841027019385211055596446229489549303819644288109756659334461284756\
482337867831652712019091456485669234603486104543266482133936072602491412737245\
870066063155881748815209209628292540917153643678925903600113305305488204665213\
841469519415116094330572703657595919530921861173819326117931051185480744623799\
62749567351885752724891227938183011949129833673363`500. \)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Eine gewisse Herausforderung bei der Gew\[ODoubleDot]hnung an ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " als neue Arbeitsumgebung stellt die Verwendung der verschiedenen \
Klammertypen dar. Wir hatten eckige Klammern, [ ], bereits als Abgrenzung der \
Argumente einer Funktion (also der Eingabewerte, auf die eine Funktion wirkt) \
kennen gelernt. Dies setzt sich konsequent fort. Man schreibt etwa:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sin[0.2]\)], "Input"],

Cell[BoxData[
    \(0.19866933079506122`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "um einen Funktionswert der Sinusfunktion abzufragen und ",
  StyleBox["Plot[f[x], {x, a, b}]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", um die Funktion ",
  StyleBox["f",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " in Abh\[ADoubleDot]ngigkeit von ",
  StyleBox["x",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " im Bereich von ",
  StyleBox["a",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " bis ",
  StyleBox["b",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " graphisch darzustellen. Erneut am Beispiel der Sinusfunktion hat man:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Sin[x], {x, 0, 10}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309015 0.294306 [
[.21429 .29651 -3 -9 ]
[.21429 .29651 3 0 ]
[.40476 .29651 -3 -9 ]
[.40476 .29651 3 0 ]
[.59524 .29651 -3 -9 ]
[.59524 .29651 3 0 ]
[.78571 .29651 -3 -9 ]
[.78571 .29651 3 0 ]
[.97619 .29651 -6 -9 ]
[.97619 .29651 6 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30901 m
.21429 .31526 L
s
[(2)] .21429 .29651 0 1 Mshowa
.40476 .30901 m
.40476 .31526 L
s
[(4)] .40476 .29651 0 1 Mshowa
.59524 .30901 m
.59524 .31526 L
s
[(6)] .59524 .29651 0 1 Mshowa
.78571 .30901 m
.78571 .31526 L
s
[(8)] .78571 .29651 0 1 Mshowa
.97619 .30901 m
.97619 .31526 L
s
[(10)] .97619 .29651 0 1 Mshowa
.125 Mabswid
.07143 .30901 m
.07143 .31276 L
s
.11905 .30901 m
.11905 .31276 L
s
.16667 .30901 m
.16667 .31276 L
s
.2619 .30901 m
.2619 .31276 L
s
.30952 .30901 m
.30952 .31276 L
s
.35714 .30901 m
.35714 .31276 L
s
.45238 .30901 m
.45238 .31276 L
s
.5 .30901 m
.5 .31276 L
s
.54762 .30901 m
.54762 .31276 L
s
.64286 .30901 m
.64286 .31276 L
s
.69048 .30901 m
.69048 .31276 L
s
.7381 .30901 m
.7381 .31276 L
s
.83333 .30901 m
.83333 .31276 L
s
.88095 .30901 m
.88095 .31276 L
s
.92857 .30901 m
.92857 .31276 L
s
.25 Mabswid
0 .30901 m
1 .30901 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .19129 m
.02756 .19129 L
s
.02381 .22072 m
.02756 .22072 L
s
.02381 .25015 m
.02756 .25015 L
s
.02381 .27958 m
.02756 .27958 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .42516 L
.08255 .47925 L
.10458 .52975 L
.11448 .54875 L
.12507 .56621 L
.13499 .5797 L
.14415 .58954 L
.14901 .59372 L
.15437 .59746 L
.15975 .6003 L
.1627 .60146 L
.16546 .6023 L
.1667 .60259 L
.16805 .60286 L
.16934 .60305 L
.17052 .60319 L
.1717 .60327 L
.17277 .60331 L
.174 .60332 L
.17516 .60327 L
.17643 .60317 L
.17707 .6031 L
.17777 .60301 L
.18017 .60258 L
.18153 .60225 L
.18298 .60184 L
.1856 .60091 L
.19088 .59838 L
.19577 .59525 L
.20684 .58538 L
.21659 .57358 L
.22696 .55801 L
.26471 .47813 L
.30491 .3646 L
.3436 .24588 L
.38474 .13133 L
.40527 .08527 L
.41527 .06645 L
.42436 .05167 L
.4332 .03954 L
.44279 .02902 L
.44806 .02443 L
.45291 .02098 L
.45756 .01838 L
.46247 .01637 L
.465 .01565 L
.46625 .01537 L
.4674 .01515 L
.46853 .01498 L
Mistroke
.46956 .01486 L
.4707 .01477 L
.47191 .01472 L
.47322 .01472 L
.47442 .01476 L
.47574 .01487 L
.4764 .01494 L
.47713 .01504 L
.47836 .01525 L
.47968 .01552 L
.48205 .01615 L
.48441 .01696 L
.48697 .01805 L
.49163 .02056 L
.50036 .02711 L
.50978 .03685 L
.52017 .05066 L
.54119 .08778 L
.58145 .18687 L
.62019 .30277 L
.66138 .42668 L
.68195 .48175 L
.70106 .52578 L
.71952 .56007 L
.72977 .57512 L
.73922 .58626 L
.74949 .59527 L
.75489 .59869 L
.75765 .60007 L
.7606 .60129 L
.7632 .60212 L
.76557 .60269 L
.76671 .6029 L
.76795 .60308 L
.76913 .6032 L
.77021 .60328 L
.77147 .60332 L
.77264 .60331 L
.77393 .60325 L
.77466 .60319 L
.77533 .60312 L
.77659 .60295 L
.77798 .6027 L
.78077 .60202 L
.7833 .60118 L
.78604 .60004 L
.79103 .59735 L
.80035 .5902 L
.81125 .57845 L
.8213 .56447 L
Mistroke
.84004 .53097 L
.86067 .48425 L
.90097 .37167 L
.93977 .25263 L
.97619 .14891 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool001<0oooo1@0000030?ooo`030000003oool0oooo0?l0oooo0`3oool001D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000E0?ooo`030000003oool0
oooo00<0oooo0P00001c0?ooo`H00000RP3oool000d0oooo100000040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0K`3oool3000000H0oooo0P0000280?ooo`005@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool02@3oool2000008H0
oooo000D0?ooo`8000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0P`3oool001/0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0880oooo000K0?ooo`030000003oool0oooo06/0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`220?ooo`006`3oool00`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0P@3oool001/0oooo00<000000?ooo`3o
ool0J@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0800oooo000K0?ooo`800000
J@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo07l0oooo000K0?ooo`030000003o
ool0oooo06P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1n0?ooo`006`3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0OP3oool0
01/0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
07d0oooo000K0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`1m0?ooo`006`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0O03oool001/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo07`0oooo000K0?ooo`800000I@3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo07/0oooo000K0?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1k0?ooo`006`3oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0NP3oool001/0oooo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo07X0oooo000K0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1i0?ooo`006`3oool0
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0N@3oool0
01/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
07P0oooo000K0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`1h0?ooo`006`3oool200000640oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`1g0?ooo`006`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0M`3oool001/0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo07L0oooo000K0?ooo`030000003oool0oooo05l0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`1f0?ooo`006`3oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0MP3oool001/0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo07D0oooo000K0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1e0?ooo`006`3oool0
0`000000oooo0?ooo`1M0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0M@3oool0
01/0oooo0P00001N0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0M03oool001/0
oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo07@0
oooo000K0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`1c0?ooo`006`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0L`3oool001/0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool01@3oool001/0oooo00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool01@3oool000P0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3o
ool01P3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo05X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1X0?oo
o`030000003oool0oooo00H0oooo00070?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`3oool00P3oool2000005/0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1X0?oo
o`030000003oool0oooo00H0oooo00000`3oool000000000000200000080oooo00@000000?ooo`3o
ool000002@3oool2000000D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo06H0oooo00<000000?ooo`3oool01`3oool000L0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00L0oooo00080?ooo`80
00002P3oool3000000@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo06D0oooo00<000000?ooo`3oool0203oool001/0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
203oool001/0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool0203oool001/0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool02@3oool0
01/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool02@3oool001/0oooo0P00001H0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`090?ooo`006`3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0;0?ooo`00
6`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0<0?ooo`006`3oool2
000005D0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo00`0oooo000K0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo00d0oooo000K0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00d0
oooo000K0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo00d0oooo000K0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00h0oooo000K
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo00h0oooo000K0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00h0oooo000K0?ooo`80
0000D`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool03`3oool001/0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool001/0oooo00<000000?ooo`3oool0D@3o
ool00`000000oooo0?ooo`130?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3o
ool001/0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool0403oool001/0oooo00<000000?ooo`3oool0D03oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0403oool001/0
oooo00<000000?ooo`3oool0;@3oool4000001l0oooo00<000000?ooo`3oool03`3oool3000002h0
oooo0`0000020?ooo`030000003oool0oooo02/0oooo0P00000W0?ooo`030000003oool0oooo00<0
oooo1@0000020?ooo`800000103oool001/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0;@3oool01P000000oooo
0?ooo`000000oooo000002`0oooo00@000000?ooo`3oool000009@3oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`010?ooo`006`3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03P3oool5
000002h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Y0?ooo`040000003o
ool0oooo000002D0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00@3oool001/0oooo0P00000`0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000_0?ooo`<000000`3oool00`000000
oooo0?ooo`0Z0?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`0]0?ooo`04
0000003oool0oooo000001h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0000000`0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`00000T
0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0040oooo000K0?ooo`030000003oool0oooo02h0oooo0P00000O0?ooo`030000003oool0
oooo0100oooo0P00000`0?ooo`<000000`3oool00`000000oooo0?ooo`0Y0?ooo`8000009@3oool0
0`000000oooo0?ooo`060?ooo`800000103oool2000000@0oooo000K0?ooo`030000003oool0oooo
04h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo
0180oooo000K0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo0180oooo000K0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01<0oooo
000K0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`1>0?ooo`030000003oool0oooo01<0oooo000K0?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01<0oooo000D0?oo
ool000003@00000001/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0000000`0oooo00<000000?ooo`3oool01@3oool001/0oooo0P00000`0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool001/0oooo0P00001=0?ooo`030000
003oool0oooo04h0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0E0?ooo`006`3o
ool2000004`0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo01D0oooo000K0?ooo`030000003oool0000004/0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo01D0oooo000K0?ooo`030000003oool00000
04/0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo
01H0oooo000K0?ooo`030000003oool0000004X0oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo01H0oooo000K0?ooo`80000000<0oooo0000003oool0
B03oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
5P3oool001/0oooo00@000000?ooo`3oool00000B@3oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool05`3oool001/0oooo00@000000?ooo`3oool00000
B@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
5`3oool001/0oooo00D000000?ooo`3oool0oooo000000170?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0G0?ooo`006`3oool01@000000oooo0?oo
o`3oool0000004L0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo01L0oooo000K0?ooo`050000003oool0oooo0?ooo`000000A`3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0603oool001/0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo05D0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`0H0?ooo`006`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo01P0oooo000K0?ooo`8000000`3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0I0?oo
o`006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo01T0oooo000K0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool06@3oool001/0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo01X0oooo000K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`1J0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool06P3oool001/0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo05/0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0K0?ooo`006`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo01/0oooo000K0?ooo`8000001P3oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0L0?ooo`006`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0G@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01`0oooo000K0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1M0?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0M0?ooo`006`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool07@3o
ool001/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo0640oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0N0?ooo`006`3oool20000
00P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool07P3oool001/0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0O0?ooo`006`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01l0oooo
000K0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool07`3oool001/0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`006`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0200oooo00080?ooo`800000103oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool000L0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool08@3oool000L0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?oo
o`8000002`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0Q0?ooo`001`3oool010000000oooo0?ooo`0000090?oo
o`8000001@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0J03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0240oooo00070?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0280oooo00080?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`0R0?ooo`006`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo02<0oooo000K0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool08`3o
ool001/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S0?ooo`006`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo02@0oooo000K0?ooo`8000003P3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0T0?ooo`006`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02@0oooo
000K0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`1_0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool09@3oool001/0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0700oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0U0?ooo`006`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo02H0oooo000K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool09P3oool001/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo07<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`006`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo000K0?ooo`8000004@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0W0?ooo`006`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
02P0oooo000K0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:03oool001/0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0Y0?ooo`006`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo02T0oooo000K0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0:P3oool001/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo07/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Z0?oo
o`006`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02/0oooo000K0?ooo`800000
5@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0[0?ooo`006`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo02`0oooo000K0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;03oool0
01/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
07l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0]0?ooo`006`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo02d0oooo000K0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0;P3oool001/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0_0?ooo`006`3oool2000001X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`25
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0<03oool001/0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo08L0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0`0?ooo`006`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0340oooo000K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
<P3oool001/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo08X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0c0?ooo`006`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo0P00002>0?ooo`8000003@3oool0
0`000000oooo0?ooo`0d0?ooo`004`3oool5000000<0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0e0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0
oooo0P0000080?ooo`800000U03oool2000000L0oooo0P00000h0?ooo`005@3oool00`000000oooo
0?ooo`030?ooo`8000008P3oool8000009P0oooo1`00000j0?ooo`005@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0?l0oooo0`3oool001D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000D0?ooo`8000001@3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.07864, -1.13005, \
0.0394728, 0.0127735}}]
}, Open  ]],

Cell[TextData[{
  "Dieser letzte Befehl stellt unseren Einstieg in komplexere \
Befehlsstrukturen dar. Hier wird die Funktion sin(",
  StyleBox["x",
    FontSlant->"Italic"],
  ") im Intervall von 0 bis 10 graphisch dargestellt. Man erkennt, dass auch \
die Argumente von ",
  StyleBox["Plot[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " durch eckige Klammern umgrenzt sind. Das erste Argument ist die \
darzustellende Funktion, das zweite Argument stellt den entsprechenden \
Wertebereich dar. Hier kommt ein weiterer Typ von Klammern zum Einsatz: \
Geschweifte Klammern, { }, geben Aneinanderreihungen (\"Listen\") von \
Elementen an. Wir werden im Folgenden noch sehen, dass diese Elemente nicht \
nur Zahlen oder Variablen sein k\[ODoubleDot]nnen, sondern auch Funktionen, \
Grafiken, T\[ODoubleDot]ne, ganze Datens\[ADoubleDot]tze und vieles mehr. \
Will man mehrere Funktionen darstellen, so reiht man sie in geschweiften \
Klammern aneinander. Der letzte Klammertyp, n\[ADoubleDot]mlich normale \
(runde) Klammern, ( ), wird in der \[UDoubleDot]blichen Weise f\[UDoubleDot]r \
das Abgrenzen mathematischer Ausdr\[UDoubleDot]cke verwendet, etwa wie bei \
der Funktion im folgenden ",
  StyleBox["Plot",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehl."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[\((1 - x)\)/\((1 + x)\)^2, \ {x, 0, 30}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.325811 2.48879 [
[.18254 .31331 -3 -9 ]
[.18254 .31331 3 0 ]
[.34127 .31331 -6 -9 ]
[.34127 .31331 6 0 ]
[.5 .31331 -6 -9 ]
[.5 .31331 6 0 ]
[.65873 .31331 -6 -9 ]
[.65873 .31331 6 0 ]
[.81746 .31331 -6 -9 ]
[.81746 .31331 6 0 ]
[.97619 .31331 -6 -9 ]
[.97619 .31331 6 0 ]
[.01131 .07693 -24 -4.5 ]
[.01131 .07693 0 4.5 ]
[.01131 .20137 -30 -4.5 ]
[.01131 .20137 0 4.5 ]
[.01131 .45025 -24 -4.5 ]
[.01131 .45025 0 4.5 ]
[.01131 .57469 -18 -4.5 ]
[.01131 .57469 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .32581 m
.18254 .33206 L
s
[(5)] .18254 .31331 0 1 Mshowa
.34127 .32581 m
.34127 .33206 L
s
[(10)] .34127 .31331 0 1 Mshowa
.5 .32581 m
.5 .33206 L
s
[(15)] .5 .31331 0 1 Mshowa
.65873 .32581 m
.65873 .33206 L
s
[(20)] .65873 .31331 0 1 Mshowa
.81746 .32581 m
.81746 .33206 L
s
[(25)] .81746 .31331 0 1 Mshowa
.97619 .32581 m
.97619 .33206 L
s
[(30)] .97619 .31331 0 1 Mshowa
.125 Mabswid
.05556 .32581 m
.05556 .32956 L
s
.0873 .32581 m
.0873 .32956 L
s
.11905 .32581 m
.11905 .32956 L
s
.15079 .32581 m
.15079 .32956 L
s
.21429 .32581 m
.21429 .32956 L
s
.24603 .32581 m
.24603 .32956 L
s
.27778 .32581 m
.27778 .32956 L
s
.30952 .32581 m
.30952 .32956 L
s
.37302 .32581 m
.37302 .32956 L
s
.40476 .32581 m
.40476 .32956 L
s
.43651 .32581 m
.43651 .32956 L
s
.46825 .32581 m
.46825 .32956 L
s
.53175 .32581 m
.53175 .32956 L
s
.56349 .32581 m
.56349 .32956 L
s
.59524 .32581 m
.59524 .32956 L
s
.62698 .32581 m
.62698 .32956 L
s
.69048 .32581 m
.69048 .32956 L
s
.72222 .32581 m
.72222 .32956 L
s
.75397 .32581 m
.75397 .32956 L
s
.78571 .32581 m
.78571 .32956 L
s
.84921 .32581 m
.84921 .32956 L
s
.88095 .32581 m
.88095 .32956 L
s
.9127 .32581 m
.9127 .32956 L
s
.94444 .32581 m
.94444 .32956 L
s
.25 Mabswid
0 .32581 m
1 .32581 L
s
.02381 .07693 m
.03006 .07693 L
s
[(-0.1)] .01131 .07693 1 0 Mshowa
.02381 .20137 m
.03006 .20137 L
s
[(-0.05)] .01131 .20137 1 0 Mshowa
.02381 .45025 m
.03006 .45025 L
s
[(0.05)] .01131 .45025 1 0 Mshowa
.02381 .57469 m
.03006 .57469 L
s
[(0.1)] .01131 .57469 1 0 Mshowa
.125 Mabswid
.02381 .10182 m
.02756 .10182 L
s
.02381 .12671 m
.02756 .12671 L
s
.02381 .1516 m
.02756 .1516 L
s
.02381 .17648 m
.02756 .17648 L
s
.02381 .22626 m
.02756 .22626 L
s
.02381 .25115 m
.02756 .25115 L
s
.02381 .27604 m
.02756 .27604 L
s
.02381 .30092 m
.02756 .30092 L
s
.02381 .3507 m
.02756 .3507 L
s
.02381 .37559 m
.02756 .37559 L
s
.02381 .40048 m
.02756 .40048 L
s
.02381 .42536 m
.02756 .42536 L
s
.02381 .47514 m
.02756 .47514 L
s
.02381 .50003 m
.02756 .50003 L
s
.02381 .52491 m
.02756 .52491 L
s
.02381 .5498 m
.02756 .5498 L
s
.02381 .05204 m
.02756 .05204 L
s
.02381 .02716 m
.02756 .02716 L
s
.02381 .00227 m
.02756 .00227 L
s
.02381 .59958 m
.02756 .59958 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.04535 .61803 m
.04756 .5309 L
.05212 .40095 L
.05713 .29635 L
.06244 .21593 L
.06743 .16062 L
.0728 .11681 L
.07786 .0864 L
.0825 .06554 L
.08791 .04755 L
.09097 .03978 L
.09382 .03384 L
.09903 .02561 L
.10194 .02225 L
.10458 .01986 L
.1069 .01819 L
.10945 .01679 L
.11074 .01624 L
.11212 .01575 L
.11331 .01541 L
.1146 .01512 L
.11589 .01491 L
.11708 .01479 L
.11822 .01473 L
.11943 .01472 L
.12051 .01475 L
.12152 .01483 L
.12263 .01495 L
.12383 .01512 L
.12635 .01563 L
.12912 .01639 L
.13469 .01845 L
.14465 .02347 L
.18521 .05121 L
.22425 .07858 L
.26575 .1041 L
.30573 .12491 L
.3442 .14189 L
.38512 .15727 L
.42452 .16994 L
.46241 .18051 L
.50275 .19033 L
.54157 .19864 L
.58285 .20645 L
.62261 .21313 L
.66085 .21889 L
.70155 .22442 L
.74073 .22923 L
.78237 .23387 L
.82249 .23794 L
Mistroke
.86109 .24154 L
.90214 .24505 L
.94168 .24817 L
.97619 .25071 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`008@3oool200000?d0oooo000Q0?ooo`030000003o
ool0oooo0?`0oooo000Q0?ooo`030000003oool0oooo0?`0oooo000Q0?ooo`030000003oool0oooo
0?`0oooo000Q0?ooo`030000003oool0oooo0180oooo1`00003S0?ooo`008@3oool00`000000oooo
0?ooo`0A0?ooo`8000001P3oool200000>40oooo000Q0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0203oool200000=l0oooo000Q0?ooo`8000004@3oool00`000000oooo0?ooo`0:
0?ooo`800000g@3oool00240oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0=X0oooo000Q0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03P3oool200000=X0oooo000Q0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
4@3oool200000=P0oooo000Q0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`3E0?ooo`008@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01D0oooo0P00003E0?ooo`008@3oool2000000h0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`3B0?ooo`008@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01P0
oooo0P00003B0?ooo`008@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0c`3oool00240oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo0<h0oooo000Q0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool07@3oool200000<h0oooo000>0?ooo`800000103oool2000000<0oooo1@0000030?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3;0?oo
o`003@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0P0?ooo`800000b`3oool000d0oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`030?ooo`800000303oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0<P0oooo00070?ooo`@000000P3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0T0?oo
o`800000b03oool000d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`350?oo
o`003P3oool2000000X0oooo0P0000050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool09`3oool200000<D0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
:P3oool200000<<0oooo000Q0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`300?ooo`008@3oool2000000/0oooo00<000000?ooo`3oool0;@3oool2
00000<00oooo000Q0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`2m0?ooo`008@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0340
oooo0P00002m0?ooo`008@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03<0oooo
0P00002k0?ooo`008@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03D0oooo0P00
002i0?ooo`008@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03L0oooo0P00002g
0?ooo`008@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03T0oooo0P00002e0?oo
o`008@3oool2000000X0oooo00<000000?ooo`3oool0>`3oool200000;<0oooo000Q0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0?@3oool200000;40oooo000Q0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0?`3oool200000:l0oooo000Q0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0@P3oool200000:d0oooo000Q0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0A03oool300000:X0oooo000Q0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0A`3oool300000:L0oooo000Q0?ooo`8000002@3oool00`000000oooo
0?ooo`1:0?ooo`800000Y@3oool00240oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`1<0?ooo`<00000XP3oool00240oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1?
0?ooo`<00000W`3oool00240oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1B0?oo
o`<00000W03oool00240oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1E0?ooo`@0
0000V03oool00240oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1I0?ooo`<00000
U@3oool00240oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1L0?ooo`<00000TP3o
ool00240oooo0P0000090?ooo`030000003oool0oooo05l0oooo1000002>0?ooo`008@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo06<0oooo1000002:0?ooo`008@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo06L0oooo1@0000250?ooo`008@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo06d0oooo1@0000200?ooo`00203oool2000000@0oooo0P00
00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`1b0?ooo`D00000N`3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`1g0?ooo`D00000MP3oool000L0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo0P0000080?ooo`030000003oool0oooo
07`0oooo1P00001`0?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000`3oool2000000D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`220?ooo`D00000J`3oool000L0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`270?ooo`D00000IP3oool000P0oooo0P00000:0?ooo`800000103oool3
000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2<0?ooo`D00000H@3oool0
0240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2A0?ooo`D00000G03oool00240
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2F0?ooo`P00000E03oool00240oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2N0?ooo`X00000BP3oool00240oooo0P00
00080?ooo`030000003oool0oooo0:P0oooo2`00000o0?ooo`008@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0;<0oooo2000000g0?ooo`008@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0;/0oooo1@00000b0?ooo`008@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0<40oooo4P00000P0?ooo`008@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0=<0oooo2P00000F0?ooo`008@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0=d0oooo2P00000<0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0i`3oool5
000000L0oooo000Q0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0l`3oool00240
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3c0?ooo`008@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0?<0oooo000Q0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0l`3oool00240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3c
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0l`3oool00240oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`3d0?ooo`008@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01d0oooo0P00000S0?ooo`D000000P3oool200000240oooo1@0000020?ooo`800000
803oool4000000<0oooo0P00000P0?ooo`@000000`3oool200000240oooo0P0000040?ooo`800000
103oool00240oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0L0?ooo`040000003o
ool0oooo000002@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0200
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000007`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0
oooo000Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0R0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000200oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`010?ooo`008@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01d0oooo0P00000U0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo0P00000R
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo0080oooo0P00000S0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0@3oool00240oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo02@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000007`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo01l0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`008@3o
ool2000000H0oooo00<000000?ooo`3oool07@3oool3000002<0oooo0P0000040?ooo`8000008P3o
ool2000000@0oooo0`00000P0?ooo`800000103oool200000240oooo0P0000040?ooo`<00000803o
ool2000000@0oooo0P0000040?ooo`008@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0?@0oooo000Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0m03oool00240
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3d0?ooo`008@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0?@0oooo000Q0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0m03oool001/0ooooo`000006000000008@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`008@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0m03oool00240oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`3d0?ooo`008@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0?@0oooo000Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0m03oool00240
oooo0P0000050?ooo`030000003oool0oooo0?D0oooo000Q0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0m@3oool00240oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`3e0?ooo`008@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?D0oooo000Q0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0m@3oool00240oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`3e0?ooo`008@3oool2000000D0oooo00<000000?ooo`3oool0
m@3oool00240oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3e0?ooo`008@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0?D0oooo000Q0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0m@3oool00240oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3e0?ooo`008@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?D0oooo
000Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0m@3oool00240oooo0P000005
0?ooo`030000003oool0oooo0?D0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0m@3oool00240oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3e0?ooo`00
8@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?D0oooo000Q0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0m@3oool00240oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3e0?ooo`008@3oool2000000D0oooo00<000000?ooo`3oool0m@3oool00240
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3e0?ooo`008@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0?D0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0m@3oool00240oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3e
0?ooo`00203oool2000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`3e0?ooo`001`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?D0oooo00070?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo
0?ooo`3e0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0
oooo0P0000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0m@3oool000L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3e0?ooo`00203oool2000000X0
oooo0P0000040?ooo`<00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?D0
oooo000Q0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0mP3oool00240oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`3f0?ooo`008@3oool2000000@0oooo00<00000
0?ooo`3oool0mP3oool00240oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3f0?oo
o`008@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?H0oooo000Q0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0mP3oool00240oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`3f0?ooo`008@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?H0oooo000Q0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0mP3oool00240
oooo0P0000040?ooo`030000003oool0oooo0?H0oooo000Q0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0mP3oool00240oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3f0?ooo`008@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?H0oooo000Q0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0mP3oool00240oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3f0?ooo`008@3oool2000000@0oooo00<000000?ooo`3oool0
mP3oool00240oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3f0?ooo`008@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0?H0oooo000Q0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0mP3oool00240oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`3f0?ooo`008@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?H0oooo
000Q0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0mP3oool00240oooo0P000004
0?ooo`030000003oool0oooo0?H0oooo000Q0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0mP3oool00240oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3f0?ooo`00
8@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?H0oooo000>0?ooo`800000103o
ool2000000<0oooo1@0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0mP3o
ool000d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0mP3oool000d0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`030?ooo`8000000`3oool00`000000oooo0?ooo`3g0?ooo`003@3oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`3g0?ooo`003@3oool010000000oooo0?ooo`00000:0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3g0?ooo`003P3oool2
000000X0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0m`3oool0
0240oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3g0?ooo`008@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0?L0oooo000Q0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0m`3oool00240oooo0P0000030?ooo`030000003oool0oooo0?L0oooo000Q
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0m`3oool00240oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0?L0oooo000Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
m`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.02939, -0.1435, 0.121183, \
0.00154576}}]
}, Open  ]],

Cell[TextData[{
  "W\[ADoubleDot]hrend eckige und geschweifte Klammern in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " syntaktische Aufgaben \[UDoubleDot]bernehmen, werden runde Klammern \
ausschlie\[SZ]lich in dieser \[UDoubleDot]blichen mathematischen Weise \
verwendet.\n\nNeben Standardbefehlen (wie z.B. ",
  StyleBox["Plot[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") stehen in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Bibliotheken mit vordefinierten Funktionen zu verschiedenen \
Themengebieten zur Verf\[UDoubleDot]gung. Durch das Einbinden eines solchen \
",
  StyleBox["Package",
    FontSlant->"Italic"],
  " sind damit alle in dieser Bibliothek enthaltenen Befehle einsetzbar. In \
der folgenden Diskussion werden wir auf Befehle zur\[UDoubleDot]ckgreifen, \
die in dem Package ",
  StyleBox["Graphics",
    FontSlant->"Italic"],
  " f\[UDoubleDot]r fortgeschrittene graphische Ausgaben vordefiniert sind. \
Durch den Befehl"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(<< Graphics`Graphics`\)], "Input"],

Cell[TextData[{
  "wird das Package geladen. In allen folgenden ",
  Cell[BoxData[
      FormBox[
        StyleBox["Mathematica",
          FontSlant->"Italic"], TraditionalForm]]],
  "-Exkursen werden zu Beginn die ben\[ODoubleDot]tigten Packages geladen.\n\n\
Nach diesem etwas formalen Einstieg, der allerdings absolut zentral ist f\
\[UDoubleDot]r unser Ziel, mit ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " zu einer gut verst\[ADoubleDot]ndlichen algorithmischen Darstellung der \
bioinformatischen Methoden zu gelangen, k\[ODoubleDot]nnen wir nun das \
Anwendungsspektrum dieses Programms genauer betrachten. In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " entspricht eine zweidimensionale Matrix (also eine Tabelle) formal einer \
Liste, deren Elemente wieder Listen sind. Ein Beispiel mit Zufallszahlen wird \
durch folgenden Befehl erzeugt:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    StyleBox[\(SeedRandom[1]\),
      FontColor->GrayLevel[0.500008]]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tab = Table[Random[], {4}, {5}]\)], "Input"],

Cell[BoxData[
    \({{0.6686926778600345`, 0.8311998722869463`, 0.7818074748209513`, 
        0.12463419022903224`, 0.9345372830959425`}, {0.6002520340808316`, 
        0.7583545830418578`, 0.9690890062889682`, 0.1256991791331959`, 
        0.5756361231168926`}, {0.7550524622030328`, 0.821438322382038`, 
        0.6046009652062657`, 0.19446459094817814`, 
        0.6573069365710422`}, {0.5595585607318685`, 0.836730788063133`, 
        0.16053645024784782`, 0.8544355039710434`, 
        0.9454356034901887`}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Befehlsstruktur ist auch hier wieder sehr klar. Die Bezeichnung ",
  StyleBox["tab",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " auf der linken Seite der Zuweisung ist ein frei w\[ADoubleDot]hlbarer \
Variablenname. Unter diesem Namen kann man die Matrix sp\[ADoubleDot]ter \
wieder aufrufen. Der ",
  StyleBox["Table",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehl hat (\[ADoubleDot]hnlich wie der ",
  StyleBox["Plot",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehl) mehrere Argumente. An erster Stelle steht der Befehl zur \
Erzeugung der einzelnen Matrixelemente. Dabei ist ",
  StyleBox["Random[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " eine Abk\[UDoubleDot]rzung f\[UDoubleDot]r ",
  StyleBox["Random[Real, {0, 1}]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ". L\[ADoubleDot]sst man die Klammern leer, werden also reellwertige \
Zufallszahlen zwischen Null und Eins ausgegeben.",
  Cell[BoxData[
      \(TraditionalForm\`\^8\)]],
  " Solche Voreinstellungen (",
  StyleBox["Default-Werte",
    FontSlant->"Italic"],
  ") kennt man aus vielen Programmen. M\[ODoubleDot]chte man nun zum Beispiel \
eine zuf\[ADoubleDot]llige ganze Zahl zwischen Eins und Sechs erzeugen, so \
geschieht dies mit dem Befehl ",
  StyleBox["Random[Integer,{1, 6}]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ". Die beiden anderen Argumente des ",
  StyleBox["Table",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehls geben die Gr\[ODoubleDot]\[SZ]e der Matrix (also vier Zeilen und \
f\[UDoubleDot]nf Spalten) an. Auch dies ist die Abk\[UDoubleDot]rzung einer l\
\[ADoubleDot]ngeren Angabe unter Ausnutzung der Default-Einstellungen. So \
steht ",
  StyleBox["{4}",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " f\[UDoubleDot]r ",
  StyleBox["{i, 1, 4}",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ". Dabei ist ",
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " ein frei w\[ADoubleDot]hlbarer Name f\[UDoubleDot]r eine Laufvariable, \
die der Reihe nach die Werte 1 bis 4 annimmt und in dem ersten ",
  StyleBox["Table",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Argument aufgerufen werden kann. F\[UDoubleDot]r diese kompliziertere \
Konstruktion werden wir noch Beispiele kennen lernen. Die Anwendung des \
Formatierungsbefehls ",
  StyleBox["MatrixForm[tab]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " stellt diese geschachtelte Liste in der \[UDoubleDot]blichen Form einer \
Matrix dar"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[tab]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.6686926778600345`", "0.8311998722869463`", 
              "0.7818074748209513`", "0.12463419022903224`", 
              "0.9345372830959425`"},
            {"0.6002520340808316`", "0.7583545830418578`", 
              "0.9690890062889682`", "0.1256991791331959`", 
              "0.5756361231168926`"},
            {"0.7550524622030328`", "0.821438322382038`", 
              "0.6046009652062657`", "0.19446459094817814`", 
              "0.6573069365710422`"},
            {"0.5595585607318685`", "0.836730788063133`", 
              "0.16053645024784782`", "0.8544355039710434`", 
              "0.9454356034901887`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Ein Zugriff auf die einzelnen Matrixelemente erfolgt in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " \[UDoubleDot]ber doppelte eckige Klammern, in denen Spaltenummer und \
Zeilennummer angegeben werden. So ergibt zum Beispiel ",
  StyleBox["tab[[1, 2]]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " gerade den Wert 0.8312. Die Matrix ",
  StyleBox["tab",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " kann nun in Graustufen dargestellt werden. Jedem Element der Matrix \
zwischen 0 (Schwarz) und 1 (Wei\[SZ]) wird eine Graustufe zugeordnet."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListDensityPlot[tab, Mesh \[Rule] False];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.192308 0.0192308 0.240385 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.21154 -0.0125 -3 -9 ]
[.21154 -0.0125 3 0 ]
[.40385 -0.0125 -3 -9 ]
[.40385 -0.0125 3 0 ]
[.59615 -0.0125 -3 -9 ]
[.59615 -0.0125 3 0 ]
[.78846 -0.0125 -3 -9 ]
[.78846 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -6 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -6 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(1)] .21154 -0.0125 0 1 Mshowa
.40385 0 m
.40385 .00625 L
s
[(2)] .40385 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(3)] .59615 -0.0125 0 1 Mshowa
.78846 0 m
.78846 .00625 L
s
[(4)] .78846 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(5)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.05769 0 m
.05769 .00375 L
s
.09615 0 m
.09615 .00375 L
s
.13462 0 m
.13462 .00375 L
s
.17308 0 m
.17308 .00375 L
s
.25 0 m
.25 .00375 L
s
.28846 0 m
.28846 .00375 L
s
.32692 0 m
.32692 .00375 L
s
.36538 0 m
.36538 .00375 L
s
.44231 0 m
.44231 .00375 L
s
.48077 0 m
.48077 .00375 L
s
.51923 0 m
.51923 .00375 L
s
.55769 0 m
.55769 .00375 L
s
.63462 0 m
.63462 .00375 L
s
.67308 0 m
.67308 .00375 L
s
.71154 0 m
.71154 .00375 L
s
.75 0 m
.75 .00375 L
s
.82692 0 m
.82692 .00375 L
s
.86538 0 m
.86538 .00375 L
s
.90385 0 m
.90385 .00375 L
s
.94231 0 m
.94231 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(1)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(2)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(3)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(4)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.21154 .99375 m
.21154 1 L
s
.40385 .99375 m
.40385 1 L
s
.59615 .99375 m
.59615 1 L
s
.78846 .99375 m
.78846 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.05769 .99625 m
.05769 1 L
s
.09615 .99625 m
.09615 1 L
s
.13462 .99625 m
.13462 1 L
s
.17308 .99625 m
.17308 1 L
s
.25 .99625 m
.25 1 L
s
.28846 .99625 m
.28846 1 L
s
.32692 .99625 m
.32692 1 L
s
.36538 .99625 m
.36538 1 L
s
.44231 .99625 m
.44231 1 L
s
.48077 .99625 m
.48077 1 L
s
.51923 .99625 m
.51923 1 L
s
.55769 .99625 m
.55769 1 L
s
.63462 .99625 m
.63462 1 L
s
.67308 .99625 m
.67308 1 L
s
.71154 .99625 m
.71154 1 L
s
.75 .99625 m
.75 1 L
s
.82692 .99625 m
.82692 1 L
s
.86538 .99625 m
.86538 1 L
s
.90385 .99625 m
.90385 1 L
s
.94231 .99625 m
.94231 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
5 string
5 4 8 [5 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B0DBCE20F6
9EC8FF2198
C7D89F33AD
93DD2AE1F9
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`003`3oool200000340oooo1@00000`0?ooo`@00000<P3oool2000003@0oooo0`00000a0?oo
o`8000001`3oool000h0oooo00@000000?ooo`3oool00000<P3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0380oooo00@000000?ooo`3oool00000=03oool00`000000oooo0?ooo`0_
0?ooo`040000003oool0oooo000000H0oooo000>0?ooo`040000003oool0oooo00000380oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0300oooo1@00
000c0?ooo`030000003oool0oooo00@0oooo000>0?ooo`040000003oool0oooo00000380oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02l0oooo00@0
00000?ooo`3oool00000<P3oool2000000L0oooo000>0?ooo`040000003oool0oooo00000380oooo
00<000000?ooo`3oool0<03oool010000000oooo0?ooo`00000a0?ooo`040000003oool0oooo0000
0380oooo00<000000?ooo`000000<P3oool00`000000oooo0?ooo`060?ooo`003`3oool200000380
oooo0P00000c0?ooo`800000<`3oool2000003@0oooo0P00000b0?ooo`<000001P3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool000X0ooooo`00000E00000080oooo000:0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`4000000@3oool10?ooo`002P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`020?ooo`4000000@3oool10?ooo`000`3oool2000000D0oooo00<000000?ooo`3o
ool0o`3ooolA0?ooo`4000000@3oool10?ooo`000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0?l0oooo4@3oool100000040oooo0@3oool00080oooo00@000000?ooo`3oool0
0000103oool300000?l0oooo3`3oool300000080oooo00020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040
oooo0@3oool00080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooocD0
/;2`=@3Kfm/e0<k>cSD0820P=@3fm_H40?ooo`4000000@3oool10?ooo`000`3oool2000000D0oooo
00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo
0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103o
ool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he
020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`
/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3o
ool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo
00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo
0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103o
ool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he
020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`
/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3o
ool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo
0P0000040?ooocD0/;2`=@3Kfm/e0<k>cSD0820P=@3fm_H30?ooo`8000000P3oool000X0oooo00<0
00000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3o
ool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool1
00000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P
83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0
fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool0
0`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<0
00000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3o
ool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool1
00000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P
83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0
fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool0
0`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<0
00000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3o
ool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool1
00000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P
83D0m_Kf103oool100000040oooo0@3oool000X0oooo0P0000040?ooocD0/;2`=@3Kfm/e0<k>cSD0
820P=@3fm_H30?ooo`8000000P3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K
=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3o
oole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<00000
0?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool0
00X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool10000
0040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0
m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K
=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3o
oole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<00000
0?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool0
00X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool10000
0040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0
m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K
=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3o
oole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo0P000004
0?ooocD0/;2`=@3Kfm/e0<k>cSD0820P=@3fm_H30?ooo`8000000P3oool000X0oooo00<000000?oo
o`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0
oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040
oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf
103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>
c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole
0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?oo
o`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0
oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040
oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf
103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>
c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole
0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?oo
o`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0
oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040
oooo0@3oool000X0oooo0P0000040?ooocD0/;2`=@3Kfm/e0<k>cSD0820P=@3fm_H30?ooo`800000
0P3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103o
ool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he
020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`
/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3o
ool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo
00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo
0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103o
ool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he
020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole0;2`
/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3o
ool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool000X0oooo
00<000000?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo
0@3oool00080oooo1@0000030?ooo`030000003oool0oooo00<0oooo=@2`/;0e0=_KfcD0c/k>=@0P
820e0?KfmP@0oooo0@0000010?ooo`40oooo00040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3ooole0;2`/3D0fm_K=@3>c/he020P83D0m_Kf103oool100000040oooo0@3oool0
00@0oooo00<000000?ooo`3oool00`3oool3000000<0oooo=@2`/;0e0=_KfcD0c/k>=@0P820e0?Kf
mP80oooo0`0000020?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo00040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3ooole09jNWSD0b<S8=Ooooole024Q8CD0V9RH
103oool100000040oooo0@3oool000<0oooo0P0000050?ooo`030000003oool0oooo00<0oooo=@2N
WYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0
oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?oo
o`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?oo
o`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0
oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo
=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2N
WYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0
oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?oo
o`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?oo
o`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0
oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo
=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`800000103ooole09jNWSD0b<S8=Ooo
oole024Q8CD0V9RH0`3oool200000080oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe
0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo
00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`03
0000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40
oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo
0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q
8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe
0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo
00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`03
0000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40
oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo
0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q
8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe
0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo
00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`03
0000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40
oooo000:0?ooo`800000103ooole09jNWSD0b<S8=Ooooole024Q8CD0V9RH0`3oool200000080oooo
000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@00
00010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e
09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8
b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0
oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000
003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo
000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@00
00010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e
09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8
b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0
oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000
003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo
000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@00
00010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e
09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`800000103ooole09jNWSD0b<S8=Ooooole024Q
8CD0V9RH0`3oool200000080oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Go
oooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo
=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003o
ool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:
0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@000001
0?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RH
V0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Go
oooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo
=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003o
ool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:
0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@000001
0?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RH
V0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Go
oooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo
=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`800000103o
oole09jNWSD0b<S8=Ooooole024Q8CD0V9RH0`3oool200000080oooo000:0?ooo`030000003oool0
oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?oo
o`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?oo
o`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0
oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo
=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2N
WYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0
oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?oo
o`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?oo
o`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0
oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8b3Gooooo
=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo000:0?ooo`030000003oool0oooo00<0oooo=@2N
WYhe0<S8b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo00020?ooo`@00000103oool0
0`000000oooo0?ooo`030?ooocD0WYjN=@38b<PeooooocD08B4Q=@2HV9P40?ooo`4000000@3oool1
0?ooo`000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo=@2NWYhe0<S8
b3Gooooo=@0Q8B4e09RHV0@0oooo0@0000010?ooo`40oooo00030?ooo`030000003oool0oooo00@0
oooo0`0000030?ooocD0WYjN=@38b<PeooooocD08B4Q=@2HV9P20?ooo`<000000P3oool000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c
=@2][Jd40?ooo`4000000@3oool10?ooo`000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00<0oooo=@37alLe0=SHf3D0WinO=@0c<c<e0:f][@@0oooo0@0000010?ooo`40oooo
00030?ooo`8000001@3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2]
[Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe
09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?oo
ocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000
oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`00
2P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`400000
0@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2]
[Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe
09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?oo
ocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000
oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`00
2P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`400000
0@3oool10?ooo`002P3oool2000000@0oooo=@37alLe0=SHf3D0WinO=@0c<c<e0:f][@<0oooo0P00
00020?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd4
0?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nO
WcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0
alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo
0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3o
ool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3o
ool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd4
0?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nO
WcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0
alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo
0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3o
ool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3o
ool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd4
0?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nO
WcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0
alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool2000000@0oooo
=@37alLe0=SHf3D0WinO=@0c<c<e0:f][@<0oooo0P0000020?ooo`002P3oool00`000000oooo0?oo
o`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool0
0`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool1
0?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?oo
o`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0
<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7
=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?oo
o`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool0
0`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool1
0?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?oo
o`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0
<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7
=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?oo
o`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool0
0`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool1
0?ooo`002P3oool2000000@0oooo=@37alLe0=SHf3D0WinO=@0c<c<e0:f][@<0oooo0P0000020?oo
o`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`40
00000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c
=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3H
f=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`03
0?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`00
0000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?oo
o`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`40
00000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c
=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3H
f=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`03
0?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`00
0000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?oo
o`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`40
00000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c
=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool2000000@0oooo=@37alLe0=SHf3D0WinO=@0c
<c<e0:f][@<0oooo0P0000020?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe
09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?oo
ocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000
oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`00
2P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`400000
0@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2]
[Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe
09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?oo
ocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`002P3oool00`000000
oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`4000000@3oool10?ooo`00
2P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd40?ooo`400000
0@3oool10?ooo`002P3oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2]
[Jd40?ooo`4000000@3oool10?ooo`000`3oool2000000D0oooo00<000000?ooo`3oool00`3ooole
0<O7acD0f=SH=@2OWile03<c<cD0[Jf]103oool100000040oooo0@3oool00080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`030?ooocD0alO7=@3Hf=Pe09nOWcD0<c<c=@2][Jd4
0?ooo`4000000@3oool10?ooo`00103oool00`000000oooo0?ooo`030?ooo`<000000`3ooole09>C
TcD0gMgM=@0Z:RXe0>7QhCD0nOWi0P3oool300000080oooo00050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040
oooo0@3oool00080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooocD0
Ti>C=@3MgMde02XZ:SD0hN7Q=@3inOT40?ooo`4000000@3oool10?ooo`000`3oool2000000D0oooo
00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo
0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103o
ool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe
0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>C
TcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3o
ool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo
00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo
0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103o
ool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe
0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>C
TcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3o
ool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo
0P0000040?ooocD0Ti>C=@3MgMde02XZ:SD0hN7Q=@3inOT30?ooo`8000000P3oool000X0oooo00<0
00000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3o
ool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool1
00000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7Q
hCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0
gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool0
0`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<0
00000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3o
ool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool1
00000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7Q
hCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0
gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool0
0`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<0
00000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3o
ool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool1
00000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7Q
hCD0nOWi103oool100000040oooo0@3oool000X0oooo0P0000040?ooocD0Ti>C=@3MgMde02XZ:SD0
hN7Q=@3inOT30?ooo`8000000P3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM
=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3o
oole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<00000
0?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool0
00X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool10000
0040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0
nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM
=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3o
oole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<00000
0?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool0
00X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool10000
0040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0
nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM
=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3o
oole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo0P000004
0?ooocD0Ti>C=@3MgMde02XZ:SD0hN7Q=@3inOT30?ooo`8000000P3oool000X0oooo00<000000?oo
o`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0
oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040
oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi
103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z
:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole
09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?oo
o`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0
oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040
oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi
103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z
:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole
09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?oo
o`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0
oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040
oooo0@3oool000X0oooo0P0000040?ooocD0Ti>C=@3MgMde02XZ:SD0hN7Q=@3inOT30?ooo`800000
0P3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103o
ool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe
0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>C
TcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3o
ool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo
00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo
0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103o
ool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe
0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3oool00`3ooole09>C
TcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo00<000000?ooo`3o
ool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool000X0oooo
00<000000?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo
0@3oool000@0oooo0`0000030?ooo`030000003oool0oooo00<0oooo=@2CTi<e0=gMgCD0:RXZ=@3Q
hN4e0?Win@@0oooo0@0000010?ooo`40oooo00050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3ooole09>CTcD0gMgM=@0Z:RXe0>7QhCD0nOWi103oool100000040oooo0@3oool0
0080oooo1@0000030?ooo`<00000o`3oool?0?ooo`<000000P3oool00080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`3o0?oooa40oooo0@0000010?ooo`40oooo00030?ooo`03
0000003oool0000000@0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`4000000@3oool10?ooo`00
103oool2000000@0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`4000000@3oool10?ooo`002P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool100000040oooo0@3oool000X0ooooo`00000E00000080oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.305885, -0.268382, 0.018939, \
0.0151512}}]
}, Open  ]],

Cell[TextData[{
  "Die in den vorangegangenen Beispielen verwendeten vordefinierten \
Funktionen stellen nur einen Bruchteil aller in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " verf\[UDoubleDot]gbaren Funktionen dar. Das gesamte Spektrum reicht von \
numerischer Integration \[UDoubleDot]ber 3D-Visualisierungen bis zur \
Verarbeitung von Symbol- und Zahlenfolgen. Da f\[UDoubleDot]r die \
Sequenzanalyse die Verarbeitung von Symbolfolgen essentiell ist, werden wir \
das zweite einf\[UDoubleDot]hrende Beispiel an dieser Problemstellung \
ausrichten. Eine Abfolge von Symbolen sei als ein Wort (oder String) gegeben. \
Dies entspricht der Formatierung, in der zum Beispiel DNA-Sequenzen in \
Datenbanken vorliegen. Ein erster Schritt ist die Zerlegung des Wortes in \
seine Elemente:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(data = "\<TCGCTTGCCGCCTGACCCAGATGGCCTGCGTTTGAA\>"\)], "Input"],

Cell[BoxData[
    \("TCGCTTGCCGCCTGACCCAGATGGCCTGCGTTTGAA"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tmp1 = Characters[data]\)], "Input"],

Cell[BoxData[
    \({"T", "C", "G", "C", "T", "T", "G", "C", "C", "G", "C", "C", "T", "G", 
      "A", "C", "C", "C", "A", "G", "A", "T", "G", "G", "C", "C", "T", "G", 
      "C", "G", "T", "T", "T", "G", "A", "A"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Eine einfache statistische Eigenschaft, die absolute \
H\[ADoubleDot]ufigkeit, mit der die Symbole A, G, C, T in dieser \
Beispielsequenz auftreten, wird als N\[ADoubleDot]chstes berechnet und durch \
ein Histogramm graphisch visualisiert. Die zugeh\[ODoubleDot]rige \
Befehlsabfolge (oder besser: Befehlsschachtelung) stellt ein erstes eigenst\
\[ADoubleDot]ndiges kleines Programm in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " dar: Auf ",
  StyleBox["tmp1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " wird der Befehl ",
  StyleBox["Count",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " angewendet. Das zweite Element von ",
  StyleBox["Count",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " ist das zu z\[ADoubleDot]hlende Element. \[CapitalUDoubleDot]ber den \
Befehl ",
  StyleBox["Map",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " werden der Reihe nach an diese zweite Position alle m\[ODoubleDot]glichen \
Symbole des Alphabets einer DNA-Sequenz gesetzt. Das ",
  StyleBox["Slot",
    FontSlant->"Italic"],
  "-Symbol ",
  StyleBox["#",
    FontFamily->"Courier New",
    FontSize->12],
  " markiert diese Position. Insgesamt hat man:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(baseCount = 
      Map[Count[tmp1, #] &, {"\<A\>", "\<G\>", "\<C\>", "\<T\>"}]\)], "Input"],

Cell[BoxData[
    \({5, 10, 12, 9}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Histogram[baseCount, FrequencyData \[Rule] True]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0.0147151 0.0490503 [
[.25 .00222 -3 -9 ]
[.25 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.75 .00222 -3 -9 ]
[.75 .00222 3 0 ]
[1 .00222 -3 -9 ]
[1 .00222 3 0 ]
[-0.0125 .11282 -6 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -6 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -12 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25 .01472 m
.25 .02097 L
s
[(1)] .25 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(2)] .5 .00222 0 1 Mshowa
.75 .01472 m
.75 .02097 L
s
[(3)] .75 .00222 0 1 Mshowa
1 .01472 m
1 .02097 L
s
[(4)] 1 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
0 .11282 m
.00625 .11282 L
s
[(2)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(4)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(6)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(8)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(10)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(12)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03924 m
.00375 .03924 L
s
0 .06377 m
.00375 .06377 L
s
0 .08829 m
.00375 .08829 L
s
0 .13734 m
.00375 .13734 L
s
0 .16187 m
.00375 .16187 L
s
0 .18639 m
.00375 .18639 L
s
0 .23544 m
.00375 .23544 L
s
0 .25997 m
.00375 .25997 L
s
0 .28449 m
.00375 .28449 L
s
0 .33354 m
.00375 .33354 L
s
0 .35807 m
.00375 .35807 L
s
0 .38259 m
.00375 .38259 L
s
0 .43164 m
.00375 .43164 L
s
0 .45617 m
.00375 .45617 L
s
0 .48069 m
.00375 .48069 L
s
0 .52974 m
.00375 .52974 L
s
0 .55427 m
.00375 .55427 L
s
0 .57879 m
.00375 .57879 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .25997 L
.25 .25997 L
.25 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .25997 L
.25 .25997 L
.25 .01472 L
0 .01472 L
s
1 0 0 r
.25 .01472 m
.25 .50522 L
.5 .50522 L
.5 .01472 L
F
0 g
.25 .01472 m
.25 .50522 L
.5 .50522 L
.5 .01472 L
.25 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .60332 L
.75 .60332 L
.75 .01472 L
F
0 g
.5 .01472 m
.5 .60332 L
.75 .60332 L
.75 .01472 L
.5 .01472 L
s
1 0 0 r
.75 .01472 m
.75 .45617 L
1 .45617 L
1 .01472 L
F
0 g
.75 .01472 m
.75 .45617 L
1 .45617 L
1 .01472 L
.75 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00D03oool5000003h0oooo100000100?ooo`800000@`3oool300000040
oooo001B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0@03oool010000000oooo
0?ooo`0000130?ooo`4000000@3oool10?ooo`00DP3oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0?`3oool500000040oooo001B0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0n0?ooo`040000003o
ool0oooo00000080oooo001B0?ooo`030000003oool0oooo03h0oooo00@000000?ooo`3oool00000
?`3oool010000000oooo0?ooo`0000110?ooo`030000003oool000000080oooo001A0?ooo`800000
@@3oool200000440oooo0P0000130?ooo`8000000P3oool00?l0oooo8@3oool000l0oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`03
0000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3o
oooo000000l000000`3oool000l0oooo00<000000?l0003o0000@03o00000`000000o`000?l00010
0?l000030000003o0000o`000400o`0000<000000?l0003o0000@@3o00000`000000oooo0?ooo`01
0?ooo`003`3oool00`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0
003o0000@03o00000`000000o`000?l000110?l000030000003oool0oooo0040oooo000?0?ooo`03
0000003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000100?l00003
0000003o0000o`000440o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?l0003o0000
@03o00000`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000
@@3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000o`000?l000100?l000030000003o
0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000110?l000030000003o
ool0oooo0040oooo000?0?ooo`030000003o0000o`000400o`0000<000000?l0003o0000@03o0000
0`000000o`000?l000100?l000030000003o0000o`000440o`0000<000000?ooo`3oool00@3oool0
00l0oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`00
0400o`0000<000000?l0003o0000@@3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000
o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000
o`000?l000110?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`000400o`00
00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`000440o`00
00<000000?ooo`3oool00@3oool000l0oooo00<000000?l0003o0000@03o00000`000000o`000?l0
00100?l000030000003o0000o`000400o`0000<000000?l0003o0000@@3o00000`000000oooo0?oo
o`010?ooo`003`3oool00`000000o`000?l000100?l000030000003o0000o`000400o`0000<00000
0?l0003o0000@03o00000`000000o`000?l000110?l000030000003oool0oooo0040oooo000?0?oo
o`030000003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000100?l0
00030000003o0000o`000440o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?l0003o
0000@03o00000`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o
0000@@3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000o`000?l000100?l000030000
003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000110?l000030000
003oool0oooo0040oooo000?0?ooo`030000003o0000o`000400o`0000<000000?l0003o0000@03o
00000`000000o`000?l000100?l000030000003o0000o`000440o`0000<000000?ooo`3oool00@3o
ool000l0oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000
o`000400o`0000<000000?l0003o0000@@3o00000`000000oooo0?ooo`010?ooo`003`3oool00`00
0000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000@03o00000`00
0000o`000?l000110?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`000400
o`0000<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`000440
o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?l0003o0000@03o00000`000000o`00
0?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000@@3o00000`000000oooo
0?ooo`010?ooo`003`3oool00`000000o`000?l000100?l000030000003o0000o`000400o`0000<0
00000?l0003o0000@03o00000`000000o`000?l000110?l000030000003oool0oooo0040oooo000?
0?ooo`030000003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l00010
0?l000030000003o0000o`000440o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?l0
003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0
003o0000@@3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000o`000?l000100?l00003
0000003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000110?l00003
0000003oool0oooo0040oooo00070?ooo`@00000103oool00`000000o`000?l000100?l000030000
003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000110?l000030000
003oool0oooo0040oooo00070?ooo`030000003oool0oooo00D0oooo00<000000?l0003o0000@03o
00000`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000@@3o
00000`000000oooo0?ooo`010?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003o0000
o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000
o`000440o`0000<000000?ooo`3oool00@3oool000T0oooo00<000000?ooo`3oool00`3oool00`00
0000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000@03o00000`00
0000o`000?l000110?l000030000003oool0oooo0040oooo00070?ooo`040000003oool0oooo0000
00@0oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`00
0400o`0000<000000?l0003o0000@@3o00000`000000oooo0?ooo`010?ooo`00203oool2000000D0
oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`000400
o`0000<000000?l0003o0000@@3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000o`00
0?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`00
0?l000110?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`000400o`0000<0
00000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`000440o`0000<0
00000?ooo`3oool00@3oool000l0oooo00<000000?l0003o0000@03o00000`000000o`000?l00010
0?l000030000003o0000o`000400o`0000<000000?l0003o0000@@3o00000`000000oooo0?ooo`01
0?ooo`003`3oool00`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0
003o0000@03o00000`000000o`000?l000110?l000030000003oool0oooo0040oooo000?0?ooo`03
0000003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000100?l00003
0000003o0000o`000440o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?l0003o0000
@03o00000`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000
@@3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000o`000?l000100?l000030000003o
0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000110?l000030000003o
ool0oooo0040oooo000?0?ooo`030000003o0000o`000400o`0000<000000?l0003o0000@03o0000
0`000000o`000?l000100?l000030000003o0000o`000440o`0000<000000?ooo`3oool00@3oool0
00l0oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`00
0400o`0000<000000?l0003o0000@@3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000
o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000
o`000?l000110?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`000400o`00
00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`000440o`00
00<000000?ooo`3oool00@3oool000l0oooo00<000000?l0003o0000@03o00000`000000o`000?l0
00100?l000030000003o0000o`000400o`0000<000000?l0003o0000@@3o00000`000000oooo0?oo
o`010?ooo`003`3oool00`000000o`000?l000100?l000030000003o0000o`000400o`0000<00000
0?l0003o0000@03o00000`000000o`000?l000110?l000030000003oool0oooo0040oooo000?0?oo
o`030000003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000100?l0
00030000003o0000o`000440o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?l0003o
0000@03o00000`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o
0000@@3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000o`000?l000100?l000030000
003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000110?l000030000
003oool0oooo0040oooo000?0?ooo`030000003o0000o`000400o`0000<000000?l0003o0000@03o
00000`000000o`000?l000100?l000030000003o0000o`000440o`0000<000000?ooo`3oool00@3o
ool000l0oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000
o`000400o`0000<000000?l0003o0000@@3o00000`000000oooo0?ooo`010?ooo`003`3oool00`00
0000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000@03o00000`00
0000o`000?l000110?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`000400
o`0000<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`000440
o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?l0003o0000@03o00000`000000o`00
0?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000@@3o00000`000000oooo
0?ooo`010?ooo`002@3oool3000000<0oooo00<000000?l0003o0000@03o00000`000000o`000?l0
00100?l000030000003o0000o`000400o`0000<000000?l0003o0000@@3o00000`000000oooo0?oo
o`010?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003o0000o`000400o`0000<00000
0?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`000440o`0000<00000
0?ooo`3oool00@3oool000L0oooo1@0000030?ooo`030000003o0000o`000400o`0000<000000?l0
003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`000440o`0000<000000?oo
o`3oool00@3oool000L0oooo00@000000?ooo`3oool00000103oool00`000000o`000?l000100?l0
00030000003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000110?l0
00030000003oool0oooo0040oooo00080?ooo`030000003oool0000000@0oooo00<000000?l0003o
0000@03o00000`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o
0000@@3o00000`000000oooo0?ooo`010?ooo`002@3oool2000000@0oooo00<000000?l0003o0000
@03o00000`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000
@@3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000o`000?l000100?l000030000003o
0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000110?l000030000003o
ool0oooo0040oooo000?0?ooo`030000003o0000o`000400o`0000<000000?l0003o0000@03o0000
0`000000o`000?l000100?l000030000003o0000o`000440o`0000<000000?ooo`3oool00@3oool0
00l0oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`00
0400o`0000<000000?l0003o0000@@3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000
o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000
o`000?l000110?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`000400o`00
00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`000440o`00
00<000000?ooo`3oool00@3oool000l0oooo00<000000?l0003o0000@03o00000`000000o`000?l0
00100?l000030000003o0000o`000400o`0000<000000?l0003o0000@@3o00000`000000oooo0?oo
o`010?ooo`003`3oool00`000000o`000?l000100?l000030000003o0000o`000400o`0000<00000
0?l0003o0000@03o00000`000000o`000?l000110?l000030000003oool0oooo0040oooo000?0?oo
o`030000003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000100?l0
00030000003o0000o`000440o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?l0003o
0000@03o00000`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o
0000@@3o00000`000000oooo0?ooo`010?ooo`003`3ooom400000480o`0000<000000?l0003o0000
@03o00000`000000o`000?l000110?l000030000003oool0oooo0040oooo000?0?ooo`030000003o
ool0oooo0400oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o
0000o`000440o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?ooo`3oool0@03oool0
0`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000@@3o0000
0`000000oooo0?ooo`010?ooo`003`3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`00
0400o`0000<000000?l0003o0000@03o00000`000000o`000?l000110?l000030000003oool0oooo
0040oooo000?0?ooo`030000003oool0oooo0400oooo00<000000?l0003o0000@03o00000`000000
o`000?l000100?l000030000003o0000o`000440o`0000<000000?ooo`3oool00@3oool000l0oooo
00<000000?ooo`3oool0@03oool00`000000o`000?l000100?l000030000003o0000o`000400o`00
00<000000?l0003o0000@@3o00000`000000oooo0?ooo`010?ooo`003`3oool200000440oooo00<0
00000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`000440o`0000<0
00000?ooo`3oool00@3oool000l0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l00010
0?l000030000003o0000o`000400o`0000<000000?l0003o0000@@3o00000`000000oooo0?ooo`01
0?ooo`003`3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`000400o`0000<000000?l0
003o0000@03o00000`000000o`000?l000110?l000030000003oool0oooo0040oooo000?0?ooo`03
0000003oool0oooo0400oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l00003
0000003o0000o`000440o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?ooo`3oool0
@03oool00`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000
@@3o00000`000000oooo0?ooo`010?ooo`001`3oool3000000D0oooo00<000000?ooo`3oool0@03o
ool00`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000@@3o
00000`000000oooo0?ooo`010?ooo`001`3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0400oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o
0000o`000440o`0000<000000?ooo`3oool00@3oool000L0oooo00@000000?ooo`3oool00000103o
ool300000400oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o
0000o`000440o`0000<000000?ooo`3oool00@3oool000L0oooo0`0000050?ooo`030000003oool0
oooo0400oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000
o`000440o`0000<000000?ooo`3oool00@3oool000P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`100?ooo`030000003o0000o`000400o`0000<000000?l0003o0000@03o00000`00
0000o`000?l000110?l000030000003oool0oooo0040oooo00080?ooo`<00000103oool00`000000
oooo0?ooo`100?ooo`030000003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000
o`000?l000110?l000030000003oool0oooo0040oooo000?0?ooo`030000003oool0oooo0400oooo
00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`000440o`00
00<000000?ooo`3oool00@3oool000l0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l0
00100?l000030000003o0000o`000400o`0000<000000?l0003o0000@@3o00000`000000oooo0?oo
o`010?ooo`003`3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`000400o`0000<00000
0?l0003o0000@03o00000`000000o`000?l000110?l000030000003oool0oooo0040oooo000?0?oo
o`800000@@3oool00`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0
003o0000@@3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000oooo0?ooo`100?ooo`03
0000003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000110?l00003
0000003oool0oooo0040oooo000?0?ooo`030000003oool0oooo0400oooo00<000000?l0003o0000
@03o00000`000000o`000?l000100?l000030000003o0000o`000440o`0000<000000?ooo`3oool0
0@3oool000l0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000100?l000030000003o
0000o`000400o`0000<000000?l0003o0000@@3o00000`000000oooo0?ooo`010?ooo`003`3oool0
0`000000oooo0?ooo`100?ooo`030000003o0000o`000400o`0000<000000?l0003o0000@03o0000
0`000000o`000?l000110?l000030000003oool0oooo0040oooo000?0?ooo`030000003oool0oooo
0400oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`00
0440o`0000<000000?ooo`3oool00@3oool000l0oooo0P0000110?ooo`030000003o0000o`000400
o`0000<000000?l0003o0000@03o00000`000000o`000?l000110?l000030000003oool0oooo0040
oooo000?0?ooo`030000003oool0oooo0400oooo00<000000?l0003o0000@03o00000`000000o`00
0?l000100?l000030000003o0000o`000440o`0000<000000?ooo`3oool00@3oool000l0oooo00<0
00000?ooo`3oool0@03oool00`000000o`000?l000100?l000030000003o0000o`000400o`0000<0
00000?l0003o0000@@3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000oooo0?ooo`10
0?ooo`030000003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l00011
0?l000030000003oool0oooo0040oooo000?0?ooo`030000003oool0oooo0400oooo00<000000?l0
003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`000440o`0000<000000?oo
o`3oool00@3oool000l0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000100?l00003
0000003o0000o`000400o`0000<000000?l0003o0000@@3o00000`000000oooo0?ooo`010?ooo`00
3`3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`000400o`0000<000000?l0003o0000
@03o00000`000000o`000?l000110?l000030000003oool0oooo0040oooo000?0?ooo`800000@@3o
ool00`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000@@3o
00000`000000oooo0?ooo`010?ooo`003`3oool00`000000oooo0?ooo`100?ooo`030000003o0000
o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000110?l000030000003oool0
oooo0040oooo000?0?ooo`030000003oool0oooo0400oooo00<000000?l0003o0000@03o00000`00
0000o`000?l000100?l000030000003o0000o`000440o`0000<000000?ooo`3oool00@3oool000l0
oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000100?l000030000003o0000o`000400
o`0000<000000?l0003o0000@@3o00000`000000oooo0?ooo`010?ooo`00203oool2000000D0oooo
00<000000?ooo`3oool0@03oool00`000000o`000?l000100?l000030000003o0000o`000400o`00
00<000000?l0003o0000@@3o00000`000000oooo0?ooo`010?ooo`001`3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0400oooo00<000000?l0003o0000@03o00000`000000o`00
0?l000100?l000030000003o0000o`000440o`0000<000000?ooo`3oool00@3oool000L0oooo00@0
00000?ooo`3oool00000103oool300000400oooo00<000000?l0003o0000@03o00000`000000o`00
0?l000100?l000030000003o0000o`000440o`0000<000000?ooo`3oool00@3oool000P0oooo0P00
00050?ooo`030000003oool0oooo0400oooo00<000000?l0003o0000@03o00000`000000o`000?l0
00100?l000030000003o0000o`000440o`0000<000000?ooo`3oool00@3oool000L0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`100?ooo`030000003o0000o`000400o`0000<0
00000?l0003o0000@03o00000`000000o`000?l000110?l000030000003oool0oooo0040oooo0008
0?ooo`8000001@3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`000400o`0000<00000
0?l0003o0000@03o00000`000000o`000?l000110?l000030000003oool0oooo0040oooo000?0?oo
o`030000003oool0oooo0400oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l0
00030000003o0000o`000440o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?ooo`3o
ool0@03oool00`000000o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o
0000@@3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000oooo0?ooo`100?ooo`030000
003o0000o`000400o`0000<000000?l0003o0000@03o00000`000000o`000?l000110?l000030000
003oool0oooo0040oooo000?0?ooo`800000@@3oool00`000000o`000?l000100?l000030000003o
0000o`000400o`0000<000000?l0003o0000@@3o00000`000000oooo0?ooo`010?ooo`003`3oool0
0`000000oooo0?ooo`100?ooo`030000003o0000o`000400o`0000<000000?l0003o0000@03o0000
0`000000o`000?l000110?l000030000003oool0oooo0040oooo000?0?ooo`030000003oool0oooo
0400oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003o0000o`00
0440o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?ooo`3oool0@03oool00`000000
o`000?l000100?l000030000003o0000o`000400o`0000<000000?l0003o0000@@3o00000`000000
oooo0?ooo`010?ooo`003`3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`000400o`00
00<000000?l0003o0000@03o00000`000000o`000?l000110?l000030000003oool0oooo0040oooo
000?0?ooo`030000003oool0oooo0400oooo00<000000?l0003o0000@03o00000`000000o`000?l0
00100?l000030000003o0000o`000440o`0000<000000?ooo`3oool00@3oool000l0oooo0P000011
0?ooo`030000003o0000o`000400o`0000<000000?l0003o0000@03o0015000000<0oooo000?0?oo
o`030000003oool0oooo0400oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l0
00030000003oool0oooo04D0oooo000?0?ooo`030000003oool0oooo0400oooo00<000000?l0003o
0000@03o00000`000000o`000?l000100?l000030000003oool0oooo04D0oooo000?0?ooo`030000
003oool0oooo0400oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000
003oool0oooo04D0oooo000?0?ooo`030000003oool0oooo0400oooo00<000000?l0003o0000@03o
00000`000000o`000?l000100?l000030000003oool0oooo04D0oooo000?0?ooo`030000003oool0
oooo0400oooo00<000000?l0003o0000@03o00000`000000o`000?l000100?l000030000003oool0
oooo04D0oooo000?0?ooo`030000003oool0oooo0400oooo00<000000?l0003o0000@03o00000`00
0000o`000?l000100?l000030000003oool0oooo04D0oooo000?0?ooo`800000@@3oool00`000000
o`000?l000100?l000030000003o0000o`000400o`0000<000000?ooo`3oool0A@3oool000l0oooo
00<000000?ooo`3oool0@03oool00`000000o`000?l000100?l000030000003o0000o`000400o`00
00<000000?ooo`3oool0A@3oool000l0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l0
00100?l000030000003o0000o`000400o`0000<000000?ooo`3oool0A@3oool000l0oooo00<00000
0?ooo`3oool0@03oool00`000000o`000?l000100?l000030000003o0000o`000400o`0000<00000
0?ooo`3oool0A@3oool000l0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000100?l0
00030000003o0000o`000400o`0000<000000?ooo`3oool0A@3oool000030?ooo`000000000000<0
00000P3oool2000000D0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l000100?l00003
0000003o0000o`000400o`0000<000000?ooo`3oool0A@3oool000<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@03oool00`000000
o`000?l000100?l000030000003o0000o`000400o`0000<000000?ooo`3oool0A@3oool000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo0`0000100?oood@0
0000@P3o00000`000000oooo0?ooo`150?ooo`000`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`230?ooo`030000003o0000o`000400
o`0000<000000?ooo`3oool0A@3oool000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0P`3oool00`000000o`000?l000100?l00003
0000003oool0oooo04D0oooo00020?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
P`3oool00`000000o`000?l000100?l000030000003oool0oooo04D0oooo000?0?ooo`030000003o
ool0oooo08<0oooo00<000000?l0003o0000@03o00000`000000oooo0?ooo`150?ooo`003`3oool0
0`000000oooo0?ooo`230?ooo`030000003o0000o`000400o`0000<000000?ooo`3oool0A@3oool0
00l0oooo0P0000240?ooo`030000003o0000o`000400o`0000<000000?ooo`3oool0A@3oool000l0
oooo00<000000?ooo`3oool0P`3oool00`000000o`000?l000100?l000030000003oool0oooo04D0
oooo000?0?ooo`030000003oool0oooo08<0oooo00<000000?l0003o0000@03o00000`000000oooo
0?ooo`150?ooo`003`3oool00`000000oooo0?ooo`230?ooo`030000003o0000o`000400o`0000<0
00000?ooo`3oool0A@3oool000l0oooo00<000000?ooo`3oool0P`3oool00`000000o`000?l00010
0?l000030000003oool0oooo04D0oooo000?0?ooo`030000003oool0oooo08<0oooo00<000000?l0
003o0000@03o00000`000000oooo0?ooo`150?ooo`003`3oool00`000000oooo0?ooo`230?ooo`03
0000003o0000o`000400o`0000<000000?ooo`3oool0A@3oool000l0oooo0P0000240?ooo`030000
003o0000o`000400o`0000<000000?ooo`3oool0A@3oool000l0oooo00<000000?ooo`3oool0P`3o
ool00`000000o`000?l000100?l000030000003oool0oooo04D0oooo000?0?ooo`030000003oool0
oooo08<0oooo00<000000?l0003o0000@03o00000`000000oooo0?ooo`150?ooo`003`3oool00`00
0000oooo0?ooo`230?ooo`030000003o0000o`000400o`0000<000000?ooo`3oool0A@3oool000l0
oooo00<000000?ooo`3oool0P`3oool00`000000o`000?l000100?l000030000003oool0oooo04D0
oooo000?0?ooo`030000003oool0oooo08<0oooo00<000000?l0003o0000@03o00000`000000oooo
0?ooo`150?ooo`003`3oool2000008@0oooo00<000000?l0003o0000@03o00000`000000oooo0?oo
o`150?ooo`003`3oool00`000000oooo0?ooo`230?ooo`030000003o0000o`000400o`0000<00000
0?ooo`3oool0A@3oool000l0oooo00<000000?ooo`3oool0P`3oool00`000000o`000?l000100?l0
00030000003oool0oooo04D0oooo000?0?ooo`030000003oool0oooo08<0oooo00<000000?l0003o
0000@03o00000`000000oooo0?ooo`150?ooo`003`3oool00`000000oooo0?ooo`230?ooo`030000
003o0000o`000400o`0000<000000?ooo`3oool0A@3oool000030?ooo`000000000000<0000000<0
oooo0000000000000P0000040?ooo`030000003oool0oooo08<0oooo00<000000?l0003o0000@03o
00000`000000oooo0?ooo`150?ooo`000`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<0
00000?ooo`3oool0P`3oool00`000000o`000?l000100?l000030000003oool0oooo04D0oooo0003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool3000008<0ooooA0000017
0?ooo`000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0o`3oool?0?ooo`000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00020?ooo`800000103oool2000000D0
oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo
003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.228699, -1.01207, \
0.0148899, 0.0758907}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Formal unterscheidet sich DNA von RNA durch die Substitution von Thymin \
durch Uracil. Diese Abschrift l\[ADoubleDot]sst sich in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " unmittelbar nachstellen:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(tmp2 = tmp1 /. "\<T\>" -> "\<U\>"\)], "Input"],

Cell[BoxData[
    \({"U", "C", "G", "C", "U", "U", "G", "C", "C", "G", "C", "C", "U", "G", 
      "A", "C", "C", "C", "A", "G", "A", "U", "G", "G", "C", "C", "U", "G", 
      "C", "G", "U", "U", "U", "G", "A", "A"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Diese Zeile liest sich als: \"Die (neue) Variable ",
  StyleBox["tmp2",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " ist gleich der Variablen ",
  StyleBox["tmp1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " unter der Ersetzung ( ",
  StyleBox["/.",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") des Symbols T durch das Symbol U\". Wenden wir uns nun einem weiteren \
\[CapitalUDoubleDot]bersetzungsvorgang zu. Nicht \[UDoubleDot]berlappende \
Tripletts von RNA (Codons) codieren die Aminos\[ADoubleDot]uren der Proteine. \
Ein einfaches Beispiel ist der erste Leserahmen, der sich direkt durch die \
Partitionierung der Sequenz in Tripletts ergibt."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(tmp3 = Partition[tmp2, 3]\)], "Input"],

Cell[BoxData[
    \({{"U", "C", "G"}, {"C", "U", "U"}, {"G", "C", "C"}, {"G", "C", 
        "C"}, {"U", "G", "A"}, {"C", "C", "C"}, {"A", "G", "A"}, {"U", "G", 
        "G"}, {"C", "C", "U"}, {"G", "C", "G"}, {"U", "U", "U"}, {"G", "A", 
        "A"}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tmp4 = tmp3 /. {x_, y_, z_} :> StringJoin[x, y, z]\)], "Input"],

Cell[BoxData[
    \({"UCG", "CUU", "GCC", "GCC", "UGA", "CCC", "AGA", "UGG", "CCU", "GCG", 
      "UUU", "GAA"}\)], "Output"]
}, Open  ]],

Cell["\<\
Um nun von der Abfolge der Codons zu einer Abfolge von \
Aminos\[ADoubleDot]uren zu gelangen, legen wir eine Ersetzungstabelle an. \
Dabei werden auch Stop-Codons ber\[UDoubleDot]cksichtigt und als Stern \
(\"*\") dargestellt:\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(codonTab = {"\<UCA\>" \[Rule] "\<S\>", "\<UCC\>" \[Rule] "\<S\>", \
"\<UCG\>" \[Rule] "\<S\>", "\<UCU\>" \[Rule] "\<S\>", "\<UUC\>" \[Rule] \
"\<F\>", "\<UUU\>" \[Rule] "\<F\>", "\<UUA\>" \[Rule] "\<L\>", "\<UUG\>" \
\[Rule] "\<L\>", "\<UAC\>" \[Rule] "\<Y\>", "\<UAU\>" \[Rule] "\<Y\>", "\<UAA\
\>" \[Rule] "\<*\>", "\<UAG\>" \[Rule] "\<*\>", "\<UGC\>" \[Rule] "\<C\>", \
"\<UGU\>" \[Rule] "\<C\>", "\<UGA\>" \[Rule] "\<*\>", "\<UGG\>" \[Rule] \
"\<W\>", "\<CUA\>" \[Rule] "\<L\>", "\<CUC\>" \[Rule] "\<L\>", "\<CUG\>" \
\[Rule] "\<L\>", "\<CUU\>" \[Rule] "\<L\>", "\<CCA\>" \[Rule] "\<P\>", "\<CCC\
\>" \[Rule] "\<P\>", "\<CCG\>" \[Rule] "\<P\>", "\<CCU\>" \[Rule] "\<P\>", \
"\<CAC\>" \[Rule] "\<H\>", "\<CAU\>" \[Rule] "\<H\>", "\<CAA\>" \[Rule] \
"\<Q\>", "\<CAG\>" \[Rule] "\<Q\>", "\<CGA\>" \[Rule] "\<R\>", "\<CGC\>" \
\[Rule] "\<R\>", "\<CGG\>" \[Rule] "\<R\>", "\<CGU\>" \[Rule] "\<R\>", "\<AUA\
\>" \[Rule] "\<I\>", "\<AUU\>" \[Rule] "\<I\>", "\<AUC\>" \[Rule] "\<I\>", \
"\<AUG\>" \[Rule] "\<M\>", "\<ACA\>" \[Rule] "\<T\>", "\<ACC\>" \[Rule] \
"\<T\>", "\<ACG\>" \[Rule] "\<T\>", "\<ACU\>" \[Rule] "\<T\>", "\<AAC\>" \
\[Rule] "\<N\>", "\<AAU\>" \[Rule] "\<N\>", "\<AAA\>" \[Rule] "\<K\>", "\<AAG\
\>" \[Rule] "\<K\>", "\<AGC\>" \[Rule] "\<S\>", "\<AGU\>" \[Rule] "\<S\>", \
"\<AGA\>" \[Rule] "\<R\>", "\<AGG\>" \[Rule] "\<R\>", "\<GUA\>" \[Rule] \
"\<V\>", "\<GUC\>" \[Rule] "\<V\>", "\<GUG\>" \[Rule] "\<V\>", "\<GUU\>" \
\[Rule] "\<V\>", "\<GCA\>" \[Rule] "\<A\>", "\<GCC\>" \[Rule] "\<A\>", "\<GCG\
\>" \[Rule] "\<A\>", "\<GCU\>" \[Rule] "\<A\>", "\<GAC\>" \[Rule] "\<D\>", \
"\<GAU\>" \[Rule] "\<D\>", "\<GAA\>" \[Rule] "\<E\>", "\<GAG\>" \[Rule] \
"\<E\>", "\<GGA\>" \[Rule] "\<G\>", "\<GGC\>" \[Rule] "\<G\>", "\<GGG\>" \
\[Rule] "\<G\>", "\<GGU\>" \[Rule] "\<G\>"};\)\)], "Input"],

Cell["\<\
Mit Hilfe des Ersetzungsbefehls werden nun die Codons in \
Aminos\[ADoubleDot]uren \[UDoubleDot]bersetzt.\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(tmp4 /. codonTab\)], "Input"],

Cell[BoxData[
    \({"S", "L", "A", "A", "*", "P", "R", "W", "P", "A", "F", 
      "E"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Den n\[ADoubleDot]chsten Leserahmen erh\[ADoubleDot]lt man, indem man die \
Partitionierung erst beim zweiten Symbol der RNA-Sequenz beginnt. Diese \
Einzelbefehle lassen sich mit Hilfe der ",
  StyleBox["Module",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Umgebung zu einer Funktion zusammenf\[UDoubleDot]gen, die unter der \
Angabe einer Sequenz und eines Leserahmens eine entsprechende Abfolge von \
Aminos\[ADoubleDot]uren ausgibt. Der ",
  StyleBox["Module",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehl l\[ADoubleDot]sst interne Variablen zu, die in Form einer Liste \
als erstes Argument angegeben werden. Zuweisungen zu diesen Variablen sind \
nur innerhalb der aktuellen ",
  StyleBox["Module",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Umgebung wirksam. Die weiteren Argumente des ",
  StyleBox["Module",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehls sind hintereinander ausgef\[UDoubleDot]hrte, durch Semikolon \
getrennte Einzelbefehle. Die Funktion ",
  StyleBox["readingFrame",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " illustriert dieses Konzept:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(readingFrame[seq_, nr_] := 
      Module[{tmp1, tmp2, tmp3, tmp4}, \[IndentingNewLine]tmp1 = 
          Characters[seq]; \[IndentingNewLine]tmp2 = 
          tmp1 /. "\<T\>" -> "\<U\>"; \[IndentingNewLine]tmp3 = 
          Partition[Drop[tmp2, nr - 1], 3]; \[IndentingNewLine]tmp4 = 
          tmp3 /. {x_, y_, z_} :> 
              StringJoin[x, y, z]; \[IndentingNewLine]tmp4 /. 
          codonTab\[IndentingNewLine]]\)], "Input"],

Cell["\<\
Die drei m\[ODoubleDot]glichen Leserahmen werden durch eine Nummer codiert.\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(readingFrame[tmp1, 2]\)], "Input"],

Cell[BoxData[
    \({"R", "L", "P", "P", "D", "P", "D", "G", "L", "R", "L"}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(readingFrame[tmp1, 3]\)], "Input"],

Cell[BoxData[
    \({"A", "C", "R", "L", "T", "Q", "M", "A", "C", "V", "*"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Wir haben also mit \[ADoubleDot]u\[SZ]erst einfachen Mitteln im Rahmen von \
",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "ein erstes bioinformatisches Werkzeug zur \[CapitalUDoubleDot]bersetzung \
einer DNA-Sequenz in eine Proteinsequenz f\[UDoubleDot]r einen \
w\[ADoubleDot]hlbaren Leserahmen entworfen. All diese Befehle sind hier nat\
\[UDoubleDot]rlich nur als Spezialf\[ADoubleDot]lle an Einzelbeispielen \
vorgef\[UDoubleDot]hrt. Die ideale Art, dieses Kapitel durchzuarbeiten, ist \
daher die Beispiele selbst zu ver\[ADoubleDot]ndern, neue Befehle \
auszuprobieren und sich so die Anwendungsvielfalt dieser Programmierumgebung \
zu erschlie\[SZ]en."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\ \^8\)\)]],
  " Die Erzeugung solcher Zufallszahlen auf einem (deterministisch, also \
gerade nicht zuf\[ADoubleDot]llig, arbeitenden) Computer ist ein eigenes \
Forschungsfeld (vgl. hierzu z.B. Knuth (1997)).\n"
}], "Text",
  CellFrame->{{0, 0}, {0, 0.5}},
  FontFamily->"Times New Roman",
  FontSize->13]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowSize->{507, 651},
WindowMargins->{{6, Automatic}, {Automatic, 1}},
ShowSelection->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3348487723-1833893"->{
    Cell[5497, 157, 353, 9, 63, "Print",
      CellTags->"Info3348487723-1833893"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3348487723-1833893", 138396, 3287}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 553, 21, 115, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2332, 76, 198, 5, 126, "Subtitle"],
Cell[2533, 83, 1702, 32, 376, "Text"],

Cell[CellGroupData[{
Cell[4260, 119, 59, 1, 30, "Input"],
Cell[4322, 122, 39, 1, 29, "Output"]
}, Open  ]],
Cell[4376, 126, 1054, 24, 205, "Text"],

Cell[CellGroupData[{
Cell[5455, 154, 39, 1, 30, "Input"],
Cell[5497, 157, 353, 9, 63, "Print",
  CellTags->"Info3348487723-1833893"]
}, Open  ]],
Cell[5865, 169, 2368, 52, 509, "Text"],

Cell[CellGroupData[{
Cell[8258, 225, 35, 1, 30, "Input"],
Cell[8296, 228, 39, 1, 29, "Output"]
}, Open  ]],
Cell[8350, 232, 594, 17, 110, "Text"],

Cell[CellGroupData[{
Cell[8969, 253, 38, 1, 30, "Input"],
Cell[9010, 256, 52, 1, 29, "Output"]
}, Open  ]],
Cell[9077, 260, 532, 13, 110, "Text"],

Cell[CellGroupData[{
Cell[9634, 277, 43, 1, 30, "Input"],
Cell[9680, 280, 564, 7, 200, "Output"]
}, Open  ]],
Cell[10259, 290, 496, 10, 128, "Text"],

Cell[CellGroupData[{
Cell[10780, 304, 41, 1, 30, "Input"],
Cell[10824, 307, 54, 1, 29, "Output"]
}, Open  ]],
Cell[10893, 311, 779, 29, 74, "Text"],

Cell[CellGroupData[{
Cell[11697, 344, 62, 1, 30, "Input"],
Cell[11762, 347, 26326, 579, 186, 4466, 305, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[38103, 929, 1392, 30, 282, "Text"],

Cell[CellGroupData[{
Cell[39520, 963, 83, 1, 30, "Input"],
Cell[39606, 966, 19493, 491, 186, 4207, 298, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[59114, 1460, 1068, 28, 224, "Text"],
Cell[60185, 1490, 54, 1, 30, "Input"],
Cell[60242, 1493, 940, 21, 204, "Text"],
Cell[61185, 1516, 94, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[61304, 1522, 64, 1, 30, "Input"],
Cell[61371, 1525, 526, 8, 86, "Output"]
}, Open  ]],
Cell[61912, 1536, 2896, 83, 404, "Text"],

Cell[CellGroupData[{
Cell[64833, 1623, 48, 1, 30, "Input"],
Cell[64884, 1626, 907, 20, 87, "Output"]
}, Open  ]],
Cell[65806, 1649, 701, 19, 130, "Text"],

Cell[CellGroupData[{
Cell[66532, 1672, 78, 1, 30, "Input"],
Cell[66613, 1675, 33977, 763, 296, 4607, 396, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[100605, 2441, 862, 16, 204, "Text"],

Cell[CellGroupData[{
Cell[101492, 2461, 82, 1, 30, "Input"],
Cell[101577, 2464, 72, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[101686, 2470, 56, 1, 30, "Input"],
Cell[101745, 2473, 228, 3, 48, "Output"]
}, Open  ]],
Cell[101988, 2479, 1369, 41, 188, "Text"],

Cell[CellGroupData[{
Cell[103382, 2524, 111, 2, 30, "Input"],
Cell[103496, 2528, 48, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[103581, 2534, 81, 1, 30, "Input"],
Cell[103665, 2537, 25940, 505, 186, 2754, 214, "GraphicsData", "PostScript", \
"Graphics"],
Cell[129608, 3044, 130, 3, 29, "Output"]
}, Open  ]],
Cell[129753, 3050, 294, 8, 71, "Text"],

Cell[CellGroupData[{
Cell[130072, 3062, 66, 1, 30, "Input"],
Cell[130141, 3065, 228, 3, 48, "Output"]
}, Open  ]],
Cell[130384, 3071, 830, 23, 130, "Text"],

Cell[CellGroupData[{
Cell[131239, 3098, 58, 1, 30, "Input"],
Cell[131300, 3101, 265, 4, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[131602, 3110, 83, 1, 30, "Input"],
Cell[131688, 3113, 125, 2, 48, "Output"]
}, Open  ]],
Cell[131828, 3118, 299, 7, 71, "Text"],
Cell[132130, 3127, 1823, 24, 350, "Input"],
Cell[133956, 3153, 178, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[134159, 3162, 49, 1, 30, "Input"],
Cell[134211, 3165, 101, 2, 29, "Output"]
}, Open  ]],
Cell[134327, 3170, 1329, 36, 228, "Text"],
Cell[135659, 3208, 453, 8, 170, "Input"],
Cell[136115, 3218, 148, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[136288, 3226, 54, 1, 30, "Input"],
Cell[136345, 3229, 89, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136471, 3235, 54, 1, 30, "Input"],
Cell[136528, 3238, 89, 1, 29, "Output"]
}, Open  ]],
Cell[136632, 3242, 752, 15, 166, "Text"],
Cell[137387, 3259, 366, 9, 98, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

